CustomCodeSnippet constructor

CustomCodeSnippet({
  1. required String label,
  2. required String value,
  3. required Set<int> cursorLocations,
})

Creates a custom code snippet.

All parameters are required. cursorLocations may be empty, in which case the cursor is placed at the end of the inserted text.

Implementation

CustomCodeSnippet({
  required this.label,
  required this.value,
  required this.cursorLocations,
});