customCodeSnippets property
A list of custom code snippets that appear in the suggestion popup.
Each CustomCodeSnippet defines a label (shown in the popup), the code to insert, and optional cursor positions within the inserted code. When a snippet with CustomCodeSnippet.cursorLocations is accepted the primary cursor is placed at the first location and secondary cursors are added at the remaining locations.
If null or empty, no custom snippets are shown.
Implementation
final List<CustomCodeSnippet>? customCodeSnippets;