multiCursorsChanged property
Whether multi-cursor positions have changed and the editor needs repaint.
Implementation
bool multiCursorsChanged = false;
Whether multi-cursor positions have changed and the editor needs repaint.
bool multiCursorsChanged = false;