BiDiSegment class

Represents a segment of text with a specific direction

Constructors

BiDiSegment(int start, int end, TextDirection direction)
const

Properties

direction → TextDirection
final
end → int
final
hashCode → int
The hash code for this object.
no setterinherited
length → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited