SyntaxHighlighter class

Constructors

SyntaxHighlighter({required Mode language, required Map<String, TextStyle> editorTheme, TextStyle? baseTextStyle, String? languageId, List<Mode> extraLanguages = const []})

Properties

baseTextStyle → TextStyle?
final
documentVersion → int
no setter
editorTheme → Map<String, TextStyle>
final
extraLanguages → List<Mode>
final
hashCode → int
The hash code for this object.
no setterinherited
language → Mode
final
languageId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyDocumentEdit(int editStart, int oldEnd, String insertedText, String fullText) → void
buildHighlightedParagraph(int lineIndex, String lineText, ParagraphStyle paragraphStyle, double fontSize, String? fontFamily, {double? width}) → Paragraph
dispose() → void
getLineSpan(int lineIndex, String lineText) → TextSpan?
invalidateAll() → void
invalidateLines(Set<int> lines) → void
invalidateRange(int startLine, int endLine) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preHighlightLines(int startLine, int endLine, String getLineText(int)) → Future<void>
toString() → String
A string representation of this object.
inherited
updateSemanticTokens(List<LspSemanticToken> tokens, String fullText) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

isolateThreshold → const int